@@ -2,10 +2,14 @@ from __future__ import annotations
 
 from joblib_windower.ndarray_windower import ndarray_windower
 from joblib_windower.ndframe_windower import ndframe_windower
+from joblib_windower.slide_ndarrays import slide_ndarrays
+from joblib_windower.slide_ndframes import slide_ndframes
 
 
 __all__ = [
     "ndarray_windower",
     "ndframe_windower",
+    "slide_ndarrays",
+    "slide_ndframes",
 ]
-__version__ = "0.3.2"
+__version__ = "0.3.3"
